@@ -26,8 +26,10 @@
 /* This is part of the per-app CORBA bootstrapping - we use this to get 
    hold of a running metaserver and such */
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
 
-#include <bonobo-activation/bonobo-activation-i18n.h>
 #include <bonobo-activation/bonobo-activation-init.h>
 #include <bonobo-activation/bonobo-activation-base-service.h>
 #include <bonobo-activation/bonobo-activation-private.h>
@@ -37,7 +39,6 @@
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE 1
 #endif
-#include "config.h"
 #include <string.h>
 #include <limits.h>
 #include <errno.h>
@@ -312,10 +313,8 @@ bonobo_activation_existing_set (const BonoboActivationBaseService *base_service,
 	if (link == NULL) {
 		ssi = g_new0 (struct SysServerInstance, 1);
 		ssi->already_running = obj;
-		ssi->username =
-			base_service->username ? g_strdup (base_service->username) : NULL;
-		ssi->hostname =
-			base_service->hostname ? g_strdup (base_service->hostname) : NULL;
+		ssi->username = g_strdup (base_service->username);
+		ssi->hostname = g_strdup (base_service->hostname);
                 ss->instances = g_slist_prepend (ss->instances, ssi);
 	} else {
 		CORBA_Object_release (ssi->already_running, ev);
@@ -697,11 +696,17 @@ static const BonoboActivationBaseServiceRegistry rloc_file = {
 static CORBA_Object
 local_re_check_fn (const Bonobo_ActivationEnvironment *environment,
                    const char                         *act_iid,
-                   gpointer                            user_data,
-                   CORBA_Environment                  *ev)
+                   gpointer                            user_data)
 {
-        return bonobo_activation_internal_service_get_extended (
-                user_data, TRUE, ev);
+        CORBA_Environment ev;
+        CORBA_Object result;
+
+        CORBA_exception_init (&ev);
+        result = bonobo_activation_internal_service_get_extended
+                (user_data, TRUE, &ev);
+        CORBA_exception_free (&ev);
+
+        return result;
 }
 
 static CORBA_Object
@@ -737,11 +742,10 @@ bonobo_activation_base_service_init (void)
                 { NULL,
                   "--ac-activate", "--ior-output-fd=%d", NULL };
         static gboolean beenhere = FALSE;
-        extern char *_server_libexecdir; /* In bonobo-activation-init.c */
 
         if (!beenhere) {
                 bonobo_activation_ac_cmd[0] =
-                        g_build_filename (_server_libexecdir,
+                        g_build_filename (_bonobo_activation_win32_get_server_libexecdir (),
                                           "bonobo-activation-server",
                                           NULL);
                 beenhere = TRUE;
